@@ -27,7 +27,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } ) ;
 
 our @EXPORT = qw();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 # Preloaded methods go here.
@@ -155,7 +155,7 @@ our @EXPORT = qw( json_to_perl );
 
 our $VERSION = '0.01';
 
-my %google ;
+our %google ;
 $google{oauth} = 'https://accounts.google.com/o/oauth2/auth';
 $google{token} = 'https://accounts.google.com/o/oauth2/token';
 
@@ -562,7 +562,7 @@ After approval, Google returns the I<Grant Code> as a query argument to
 the redirect_uri.  Any output generated by the redirect_uri is displayed to
 the user. 
 
-=head3 Generate a token
+=head2 Generate a token
 
 The best way to generate a token is to load the following code into a 
 CGI script or a similar technique that allows the HTTP server to initiate
@@ -984,7 +984,7 @@ Upon completion, delete the local.pm file.  Or if secure, use it for future
 reference.
 
 
-=head2 EXPORT
+=head1 EXPORT
 
 C<Google::OAuth::Client::json_to_perl> is exported.
 
